=========
ChangeLog
=========


v0.6.3
======

* Added check for egg vs. not-egg in unit tests


v0.6.2
======

* Removed distribute dependency (thanks jlec)


v0.6.1
======

* Added Python 3 support


v0.6
====

* Added more standard file object compatibility (stream iteration,
  reading with size, and closing)


v0.0.5
======

* Promoted to "stable" development status
* First tagged release
* Added `asset.version()` helper function
